@@ -1,9 +1,12 @@
+from functools import total_ordering
+
 import six
 
 from .. import i18n
 from ..utils import str_coercible
 
 
+@total_ordering
 @str_coercible
 class Country(object):
     """
@@ -95,6 +98,13 @@ class Country(object):
     def __ne__(self, other):
         return not (self == other)
 
+    def __lt__(self, other):
+        if isinstance(other, Country):
+            return self.code < other.code
+        elif isinstance(other, six.string_types):
+            return self.code < other
+        return NotImplemented
+
     def __repr__(self):
         return '%s(%r)' % (self.__class__.__name__, self.code)
 
